==> openGion_dev_5.1.1.0.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF70S.sql <==
/**************************************************************************/
/* GF70 ( JSPチェック結果テーブル )                                       */
/*                                                                        */
/* Created : 2009/11/17 09:27:39                                          */
/**************************************************************************/
CREATE TABLE GF70 (
   SYSTEM_ID VARCHAR(10)                 NOT NULL                                 /* 10  システムID   */
 , PRE_FIX   VARCHAR(10)                 NOT NULL                                 /* 18  名前空間     */
 , ADDRESS   VARCHAR(256)                                                         /* 20  アドレス     */
 , FILENAME  VARCHAR(30)                                                          /* 30  ファイル名   */
 , FILEPATH  VARCHAR(256)                                                         /* 40  ファイルパス */
 , MODIFIED  VARCHAR(14)                                                          /* 50  最終更新日   */
 , TAGNAME   VARCHAR(30)                                                          /* 60  タグ名称     */
 , MSGCD     VARCHAR(20)                                                          /* 70  メッセージID */
 , MSGTXT    VARCHAR(500)                                                         /* 80  内容         */
 , TEXT_DATA TEXT                                                                 /* 90  テキスト     */
 , FGOMIT    VARCHAR(1)      DEFAULT '0' NOT NULL                                 /* 100 除外フラグ   */
 , UNIQ      BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 800 ユニークキー */
 , FGJ       VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 810 状態フラグ   */
 , DYSET     VARCHAR(14)                                                          /* 820 登録日時     */
 , PGSET     VARCHAR(10)                                                          /* 830 作成PG       */
 , PGPSET    VARCHAR(10)                                                          /* 840 作成親PG     */
 , USRSET    VARCHAR(10)                                                          /* 850 作成社員     */
 , DYUPD     VARCHAR(14)                                                          /* 860 更新日時     */
 , PGUPD     VARCHAR(10)                                                          /* 870 更新PG       */
 , PGPUPD    VARCHAR(10)                                                          /* 880 更新親PG     */
 , USRUPD    VARCHAR(10)                                                          /* 890 更新者       */
);

==> openGion_dev_5.1.1.2.zip: opengion/uap/webapps/gf/db/mysql/sql/01_TABLE/GF70S.sql <==
/**************************************************************************/
/* GF70 ( JSPチェック結果テーブル )                                       */
/*                                                                        */
/* Created : 2009/12/10 12:30:01                                          */
/**************************************************************************/
CREATE TABLE GF70 (
   SYSTEM_ID VARCHAR(10)                 NOT NULL                                 /* 10  システムID   */
 , PRE_FIX   VARCHAR(10)                 NOT NULL                                 /* 18  名前空間     */
 , ADDRESS   VARCHAR(256)                                                         /* 20  アドレス     */
 , FILENAME  VARCHAR(30)                                                          /* 30  ファイル名   */
 , FILEPATH  VARCHAR(256)                                                         /* 40  ファイルパス */
 , MODIFIED  VARCHAR(14)                                                          /* 50  最終更新日   */
 , TAGNAME   VARCHAR(30)                                                          /* 60  タグ名称     */
 , MSGCD     VARCHAR(20)                                                          /* 70  メッセージID */
 , MSGTXT    TEXT                                                                 /* 80  内容         */
 , TEXT_DATA TEXT                                                                 /* 90  テキスト     */
 , FGOMIT    VARCHAR(1)      DEFAULT '0' NOT NULL                                 /* 100 除外フラグ   */
 , UNIQ      BIGINT                      NOT NULL PRIMARY KEY AUTO_INCREMENT      /* 800 ユニークキー */
 , FGJ       VARCHAR(1)      DEFAULT '1' NOT NULL                                 /* 810 状態フラグ   */
 , DYSET     VARCHAR(14)                                                          /* 820 登録日時     */
 , PGSET     VARCHAR(10)                                                          /* 830 作成PG       */
 , PGPSET    VARCHAR(10)                                                          /* 840 作成親PG     */
 , USRSET    VARCHAR(10)                                                          /* 850 作成社員     */
 , DYUPD     VARCHAR(14)                                                          /* 860 更新日時     */
 , PGUPD     VARCHAR(10)                                                          /* 870 更新PG       */
 , PGPUPD    VARCHAR(10)                                                          /* 880 更新親PG     */
 , USRUPD    VARCHAR(10)                                                          /* 890 更新者       */
);
